@@ -4,7 +4,7 @@ from typing import List, Optional, Dict
 
 class EvalEventData(BaseModel):
     request_id: str
-    meta: Optional[Meta]
+    webhooks: str
     images: List[Image]
     model_name: str
     model_id: str
