@@ -1,9 +1,9 @@
 from pydantic import (
     BaseModel,
-    HttpUrl, root_validator
+    root_validator
 )
 
-from typing import Optional, List
+from typing import Optional, List, Dict
 
 from captur_ml_sdk.dtypes.generics import Image, TrainingMeta
 from captur_ml_sdk.dtypes.interfaces.validators import check_images_or_imagefile_has_data
@@ -19,5 +19,6 @@ class PreRunEventData(BaseModel):
     include_data: Optional[str]
     exclude_classes: Optional[List[str]]
     base_dataset_id: Optional[str]
+    mapping: Optional[Dict[str, Dict[str, str]]]
 
     root_validator(check_images_or_imagefile_has_data)
